# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class IndicatorFilterResponse(Model):
    """IndicatorFilterResponse.

    All required parameters must be populated in order to send to Azure.

    :param id: Required.
    :type id: str
    :param name: Required.
    :type name: str
    :param is_global: Required.
    :type is_global: bool
    :param indicator_types:
    :type indicator_types: list[str]
    :param sort_order:
    :type sort_order: int
    :param tags:
    :type tags: list[~smartdiagnostics_sdk.models.TagChild]
    :param location:
    :type location: ~smartdiagnostics_sdk.models.LocationChild
    :param system:
    :type system: ~smartdiagnostics_sdk.models.SystemChild
    """

    _validation = {
        'id': {'required': True},
        'name': {'required': True},
        'is_global': {'required': True},
    }

    _attribute_map = {
        'id': {'key': 'Id', 'type': 'str'},
        'name': {'key': 'Name', 'type': 'str'},
        'is_global': {'key': 'IsGlobal', 'type': 'bool'},
        'indicator_types': {'key': 'IndicatorTypes', 'type': '[str]'},
        'sort_order': {'key': 'SortOrder', 'type': 'int'},
        'tags': {'key': 'Tags', 'type': '[TagChild]'},
        'location': {'key': 'Location', 'type': 'LocationChild'},
        'system': {'key': 'System', 'type': 'SystemChild'},
    }

    def __init__(self, *, id: str, name: str, is_global: bool, indicator_types=None, sort_order: int=None, tags=None, location=None, system=None, **kwargs) -> None:
        super(IndicatorFilterResponse, self).__init__(**kwargs)
        self.id = id
        self.name = name
        self.is_global = is_global
        self.indicator_types = indicator_types
        self.sort_order = sort_order
        self.tags = tags
        self.location = location
        self.system = system



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class RoiResponse(Model):
    """RoiResponse.

    :param savings:
    :type savings: float
    :param roi_percentage:
    :type roi_percentage: float
    :param roi_ratio:
    :type roi_ratio: float
    """

    _attribute_map = {
        'savings': {'key': 'Savings', 'type': 'float'},
        'roi_percentage': {'key': 'RoiPercentage', 'type': 'float'},
        'roi_ratio': {'key': 'RoiRatio', 'type': 'float'},
    }

    def __init__(self, **kwargs):
        super(RoiResponse, self).__init__(**kwargs)
        self.savings = kwargs.get('savings', None)
        self.roi_percentage = kwargs.get('roi_percentage', None)
        self.roi_ratio = kwargs.get('roi_ratio', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class DashboardPermissionsUpdateRequest(Model):
    """DashboardPermissionsUpdateRequest.

    All required parameters must be populated in order to send to Azure.

    :param is_sentry_managed: Required.
    :type is_sentry_managed: bool
    :param is_visible_to_customers: Required.
    :type is_visible_to_customers: bool
    """

    _validation = {
        'is_sentry_managed': {'required': True},
        'is_visible_to_customers': {'required': True},
    }

    _attribute_map = {
        'is_sentry_managed': {'key': 'IsSentryManaged', 'type': 'bool'},
        'is_visible_to_customers': {'key': 'IsVisibleToCustomers', 'type': 'bool'},
    }

    def __init__(self, **kwargs):
        super(DashboardPermissionsUpdateRequest, self).__init__(**kwargs)
        self.is_sentry_managed = kwargs.get('is_sentry_managed', None)
        self.is_visible_to_customers = kwargs.get('is_visible_to_customers', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class HierarchyChild(Model):
    """HierarchyChild.

    :param hierarchy_id:
    :type hierarchy_id: str
    :param hierarchy_name:
    :type hierarchy_name: str
    :param hierarchy_abbreviation:
    :type hierarchy_abbreviation: str
    :param hierarchy_type:
    :type hierarchy_type: str
    """

    _attribute_map = {
        'hierarchy_id': {'key': 'HierarchyId', 'type': 'str'},
        'hierarchy_name': {'key': 'HierarchyName', 'type': 'str'},
        'hierarchy_abbreviation': {'key': 'HierarchyAbbreviation', 'type': 'str'},
        'hierarchy_type': {'key': 'HierarchyType', 'type': 'str'},
    }

    def __init__(self, *, hierarchy_id: str=None, hierarchy_name: str=None, hierarchy_abbreviation: str=None, hierarchy_type: str=None, **kwargs) -> None:
        super(HierarchyChild, self).__init__(**kwargs)
        self.hierarchy_id = hierarchy_id
        self.hierarchy_name = hierarchy_name
        self.hierarchy_abbreviation = hierarchy_abbreviation
        self.hierarchy_type = hierarchy_type



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class IndicatorGroupUpdateRequest(Model):
    """IndicatorGroupUpdateRequest.

    All required parameters must be populated in order to send to Azure.

    :param name: Required.
    :type name: str
    :param abbreviation:
    :type abbreviation: str
    :param is_paused: Required.
    :type is_paused: bool
    """

    _validation = {
        'name': {'required': True, 'max_length': 100},
        'abbreviation': {'max_length': 5},
        'is_paused': {'required': True},
    }

    _attribute_map = {
        'name': {'key': 'Name', 'type': 'str'},
        'abbreviation': {'key': 'Abbreviation', 'type': 'str'},
        'is_paused': {'key': 'IsPaused', 'type': 'bool'},
    }

    def __init__(self, *, name: str, is_paused: bool, abbreviation: str=None, **kwargs) -> None:
        super(IndicatorGroupUpdateRequest, self).__init__(**kwargs)
        self.name = name
        self.abbreviation = abbreviation
        self.is_paused = is_paused



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class WidgetTemplateFilterChild(Model):
    """WidgetTemplateFilterChild.

    All required parameters must be populated in order to send to Azure.

    :param filter_data_field_code: Required.
    :type filter_data_field_code: str
    :param filter_data_field_name: Required.
    :type filter_data_field_name: str
    :param filter_operator: Required.
    :type filter_operator: str
    :param filter_value: Required.
    :type filter_value: str
    """

    _validation = {
        'filter_data_field_code': {'required': True},
        'filter_data_field_name': {'required': True},
        'filter_operator': {'required': True},
        'filter_value': {'required': True},
    }

    _attribute_map = {
        'filter_data_field_code': {'key': 'FilterDataFieldCode', 'type': 'str'},
        'filter_data_field_name': {'key': 'FilterDataFieldName', 'type': 'str'},
        'filter_operator': {'key': 'FilterOperator', 'type': 'str'},
        'filter_value': {'key': 'FilterValue', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(WidgetTemplateFilterChild, self).__init__(**kwargs)
        self.filter_data_field_code = kwargs.get('filter_data_field_code', None)
        self.filter_data_field_name = kwargs.get('filter_data_field_name', None)
        self.filter_operator = kwargs.get('filter_operator', None)
        self.filter_value = kwargs.get('filter_value', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class JobModelV3(Model):
    """JobModelV3.

    All required parameters must be populated in order to send to Azure.

    :param id: Required.
    :type id: str
    :param location_name:
    :type location_name: str
    :param location_id:
    :type location_id: str
    :param corporation_name:
    :type corporation_name: str
    :param corporation_id:
    :type corporation_id: str
    :param user_name:
    :type user_name: str
    :param type:
    :type type: str
    :param status: Possible values include: 'Queued', 'Running', 'Finished',
     'FinishedWithErrors', 'Errored', 'Deferred'
    :type status: str or ~smartdiagnostics_sdk.models.enum
    :param upload_date:
    :type upload_date: datetime
    :param uploaded_file_name:
    :type uploaded_file_name: str
    """

    _validation = {
        'id': {'required': True},
    }

    _attribute_map = {
        'id': {'key': 'Id', 'type': 'str'},
        'location_name': {'key': 'LocationName', 'type': 'str'},
        'location_id': {'key': 'LocationId', 'type': 'str'},
        'corporation_name': {'key': 'CorporationName', 'type': 'str'},
        'corporation_id': {'key': 'CorporationId', 'type': 'str'},
        'user_name': {'key': 'UserName', 'type': 'str'},
        'type': {'key': 'Type', 'type': 'str'},
        'status': {'key': 'Status', 'type': 'str'},
        'upload_date': {'key': 'UploadDate', 'type': 'iso-8601'},
        'uploaded_file_name': {'key': 'UploadedFileName', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(JobModelV3, self).__init__(**kwargs)
        self.id = kwargs.get('id', None)
        self.location_name = kwargs.get('location_name', None)
        self.location_id = kwargs.get('location_id', None)
        self.corporation_name = kwargs.get('corporation_name', None)
        self.corporation_id = kwargs.get('corporation_id', None)
        self.user_name = kwargs.get('user_name', None)
        self.type = kwargs.get('type', None)
        self.status = kwargs.get('status', None)
        self.upload_date = kwargs.get('upload_date', None)
        self.uploaded_file_name = kwargs.get('uploaded_file_name', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class HardwareRevisionChild(Model):
    """HardwareRevisionChild.

    :param hardware_revision_id:
    :type hardware_revision_id: int
    :param hardware_revision_name:
    :type hardware_revision_name: str
    """

    _attribute_map = {
        'hardware_revision_id': {'key': 'HardwareRevisionId', 'type': 'int'},
        'hardware_revision_name': {'key': 'HardwareRevisionName', 'type': 'str'},
    }

    def __init__(self, *, hardware_revision_id: int=None, hardware_revision_name: str=None, **kwargs) -> None:
        super(HardwareRevisionChild, self).__init__(**kwargs)
        self.hardware_revision_id = hardware_revision_id
        self.hardware_revision_name = hardware_revision_name



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class PagedResultsModelGroupAlertsResponse(Model):
    """PagedResultsModelGroupAlertsResponse.

    :param result: Contains a list of paged items
    :type result: list[~smartdiagnostics_sdk.models.GroupAlertsResponse]
    :param total: The total number of items returned from a query (not just
     those in the paged results list)
    :type total: int
    :param total_pages: The total number of pages of items that will be
     returned
    :type total_pages: int
    :param current_page: The current page of data that is being returned
    :type current_page: int
    :param page_size: The size of the page being returned
    :type page_size: int
    """

    _attribute_map = {
        'result': {'key': 'Result', 'type': '[GroupAlertsResponse]'},
        'total': {'key': 'Total', 'type': 'int'},
        'total_pages': {'key': 'TotalPages', 'type': 'int'},
        'current_page': {'key': 'CurrentPage', 'type': 'int'},
        'page_size': {'key': 'PageSize', 'type': 'int'},
    }

    def __init__(self, **kwargs):
        super(PagedResultsModelGroupAlertsResponse, self).__init__(**kwargs)
        self.result = kwargs.get('result', None)
        self.total = kwargs.get('total', None)
        self.total_pages = kwargs.get('total_pages', None)
        self.current_page = kwargs.get('current_page', None)
        self.page_size = kwargs.get('page_size', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ReceiverChild(Model):
    """ReceiverChild.

    All required parameters must be populated in order to send to Azure.

    :param receiver_id: Required.
    :type receiver_id: long
    :param receiver_serial_number: Required.
    :type receiver_serial_number: str
    :param receiver_nickname:
    :type receiver_nickname: str
    :param receiver_firmware_version:
    :type receiver_firmware_version: str
    :param receiver_network_id:
    :type receiver_network_id: str
    :param receiver_rf_channel:
    :type receiver_rf_channel: int
    :param receiver_pending_rf_channel:
    :type receiver_pending_rf_channel: int
    """

    _validation = {
        'receiver_id': {'required': True},
        'receiver_serial_number': {'required': True},
    }

    _attribute_map = {
        'receiver_id': {'key': 'ReceiverId', 'type': 'long'},
        'receiver_serial_number': {'key': 'ReceiverSerialNumber', 'type': 'str'},
        'receiver_nickname': {'key': 'ReceiverNickname', 'type': 'str'},
        'receiver_firmware_version': {'key': 'ReceiverFirmwareVersion', 'type': 'str'},
        'receiver_network_id': {'key': 'ReceiverNetworkId', 'type': 'str'},
        'receiver_rf_channel': {'key': 'ReceiverRfChannel', 'type': 'int'},
        'receiver_pending_rf_channel': {'key': 'ReceiverPendingRfChannel', 'type': 'int'},
    }

    def __init__(self, **kwargs):
        super(ReceiverChild, self).__init__(**kwargs)
        self.receiver_id = kwargs.get('receiver_id', None)
        self.receiver_serial_number = kwargs.get('receiver_serial_number', None)
        self.receiver_nickname = kwargs.get('receiver_nickname', None)
        self.receiver_firmware_version = kwargs.get('receiver_firmware_version', None)
        self.receiver_network_id = kwargs.get('receiver_network_id', None)
        self.receiver_rf_channel = kwargs.get('receiver_rf_channel', None)
        self.receiver_pending_rf_channel = kwargs.get('receiver_pending_rf_channel', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ReceiverResponse(Model):
    """ReceiverResponse.

    :param id:
    :type id: long
    :param serial_number:
    :type serial_number: str
    :param firmware_version:
    :type firmware_version: str
    :param network_id:
    :type network_id: str
    :param receiver_type: Possible values include: 'BaseStation', 'Repeater'
    :type receiver_type: str or ~smartdiagnostics_sdk.models.enum
    :param rf_channel:
    :type rf_channel: int
    :param pending_rf_channel:
    :type pending_rf_channel: int
    :param mac_address:
    :type mac_address: str
    :param radio_mac_address:
    :type radio_mac_address: str
    :param location:
    :type location: ~smartdiagnostics_sdk.models.LocationChild
    :param corporation:
    :type corporation: ~smartdiagnostics_sdk.models.CorporationChild
    :param nodes:
    :type nodes: list[~smartdiagnostics_sdk.models.NodeChild]
    :param nickname:
    :type nickname: str
    """

    _attribute_map = {
        'id': {'key': 'Id', 'type': 'long'},
        'serial_number': {'key': 'SerialNumber', 'type': 'str'},
        'firmware_version': {'key': 'FirmwareVersion', 'type': 'str'},
        'network_id': {'key': 'NetworkId', 'type': 'str'},
        'receiver_type': {'key': 'ReceiverType', 'type': 'str'},
        'rf_channel': {'key': 'RfChannel', 'type': 'int'},
        'pending_rf_channel': {'key': 'PendingRfChannel', 'type': 'int'},
        'mac_address': {'key': 'MacAddress', 'type': 'str'},
        'radio_mac_address': {'key': 'RadioMacAddress', 'type': 'str'},
        'location': {'key': 'Location', 'type': 'LocationChild'},
        'corporation': {'key': 'Corporation', 'type': 'CorporationChild'},
        'nodes': {'key': 'Nodes', 'type': '[NodeChild]'},
        'nickname': {'key': 'Nickname', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(ReceiverResponse, self).__init__(**kwargs)
        self.id = kwargs.get('id', None)
        self.serial_number = kwargs.get('serial_number', None)
        self.firmware_version = kwargs.get('firmware_version', None)
        self.network_id = kwargs.get('network_id', None)
        self.receiver_type = kwargs.get('receiver_type', None)
        self.rf_channel = kwargs.get('rf_channel', None)
        self.pending_rf_channel = kwargs.get('pending_rf_channel', None)
        self.mac_address = kwargs.get('mac_address', None)
        self.radio_mac_address = kwargs.get('radio_mac_address', None)
        self.location = kwargs.get('location', None)
        self.corporation = kwargs.get('corporation', None)
        self.nodes = kwargs.get('nodes', None)
        self.nickname = kwargs.get('nickname', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AssetCategoryMarkerChild(Model):
    """AssetCategoryMarkerChild.

    :param category_marker_id:
    :type category_marker_id: int
    :param category_marker_name:
    :type category_marker_name: str
    :param category_marker_code:
    :type category_marker_code: str
    """

    _attribute_map = {
        'category_marker_id': {'key': 'CategoryMarkerId', 'type': 'int'},
        'category_marker_name': {'key': 'CategoryMarkerName', 'type': 'str'},
        'category_marker_code': {'key': 'CategoryMarkerCode', 'type': 'str'},
    }

    def __init__(self, *, category_marker_id: int=None, category_marker_name: str=None, category_marker_code: str=None, **kwargs) -> None:
        super(AssetCategoryMarkerChild, self).__init__(**kwargs)
        self.category_marker_id = category_marker_id
        self.category_marker_name = category_marker_name
        self.category_marker_code = category_marker_code



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ProfileChild(Model):
    """ProfileChild.

    :param acceleration_units:
    :type acceleration_units: str
    :param pressure_units:
    :type pressure_units: str
    :param temperature_units:
    :type temperature_units: str
    :param velocity_units:
    :type velocity_units: str
    :param last_updated_time:
    :type last_updated_time: datetime
    :param date_format:
    :type date_format: str
    :param time_format:
    :type time_format: str
    :param time_zones:
    :type time_zones: str
    """

    _attribute_map = {
        'acceleration_units': {'key': 'AccelerationUnits', 'type': 'str'},
        'pressure_units': {'key': 'PressureUnits', 'type': 'str'},
        'temperature_units': {'key': 'TemperatureUnits', 'type': 'str'},
        'velocity_units': {'key': 'VelocityUnits', 'type': 'str'},
        'last_updated_time': {'key': 'LastUpdatedTime', 'type': 'iso-8601'},
        'date_format': {'key': 'DateFormat', 'type': 'str'},
        'time_format': {'key': 'TimeFormat', 'type': 'str'},
        'time_zones': {'key': 'TimeZones', 'type': 'str'},
    }

    def __init__(self, *, acceleration_units: str=None, pressure_units: str=None, temperature_units: str=None, velocity_units: str=None, last_updated_time=None, date_format: str=None, time_format: str=None, time_zones: str=None, **kwargs) -> None:
        super(ProfileChild, self).__init__(**kwargs)
        self.acceleration_units = acceleration_units
        self.pressure_units = pressure_units
        self.temperature_units = temperature_units
        self.velocity_units = velocity_units
        self.last_updated_time = last_updated_time
        self.date_format = date_format
        self.time_format = time_format
        self.time_zones = time_zones



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class SystemUpdateRequest(Model):
    """SystemUpdateRequest.

    All required parameters must be populated in order to send to Azure.

    :param name: Required.
    :type name: str
    :param abbreviation:
    :type abbreviation: str
    :param is_paused: Required.
    :type is_paused: bool
    :param description:
    :type description: str
    :param is_visible: Required.
    :type is_visible: bool
    :param active: Required.
    :type active: bool
    :param cds_master_system_ids:
    :type cds_master_system_ids: list[str]
    :param cds_base_station_ids:
    :type cds_base_station_ids: list[long]
    """

    _validation = {
        'name': {'required': True, 'max_length': 100},
        'abbreviation': {'max_length': 5},
        'is_paused': {'required': True},
        'description': {'max_length': 1000},
        'is_visible': {'required': True},
        'active': {'required': True},
    }

    _attribute_map = {
        'name': {'key': 'Name', 'type': 'str'},
        'abbreviation': {'key': 'Abbreviation', 'type': 'str'},
        'is_paused': {'key': 'IsPaused', 'type': 'bool'},
        'description': {'key': 'Description', 'type': 'str'},
        'is_visible': {'key': 'IsVisible', 'type': 'bool'},
        'active': {'key': 'Active', 'type': 'bool'},
        'cds_master_system_ids': {'key': 'CdsMasterSystemIds', 'type': '[str]'},
        'cds_base_station_ids': {'key': 'CdsBaseStationIds', 'type': '[long]'},
    }

    def __init__(self, *, name: str, is_paused: bool, is_visible: bool, active: bool, abbreviation: str=None, description: str=None, cds_master_system_ids=None, cds_base_station_ids=None, **kwargs) -> None:
        super(SystemUpdateRequest, self).__init__(**kwargs)
        self.name = name
        self.abbreviation = abbreviation
        self.is_paused = is_paused
        self.description = description
        self.is_visible = is_visible
        self.active = active
        self.cds_master_system_ids = cds_master_system_ids
        self.cds_base_station_ids = cds_base_station_ids



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ActivityCodeResponse(Model):
    """ActivityCodeResponse.

    All required parameters must be populated in order to send to Azure.

    :param id: Required.
    :type id: str
    :param name: Required.
    :type name: str
    :param activity_category: Required. Possible values include:
     'SamplingFrequencyChange', 'Description', 'None', 'OperationalCondition',
     'Fault', 'RootCause', 'Evidence', 'Inspection', 'PreventativeMaintenance',
     'CorrectiveMaintenance', 'Observation', 'Document',
     'PendingSamplingFrequencyChange', 'AutoInvalidBurstData',
     'UserInvalidBurstData'
    :type activity_category: str or ~smartdiagnostics_sdk.models.enum
    """

    _validation = {
        'id': {'required': True},
        'name': {'required': True},
        'activity_category': {'required': True},
    }

    _attribute_map = {
        'id': {'key': 'Id', 'type': 'str'},
        'name': {'key': 'Name', 'type': 'str'},
        'activity_category': {'key': 'ActivityCategory', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(ActivityCodeResponse, self).__init__(**kwargs)
        self.id = kwargs.get('id', None)
        self.name = kwargs.get('name', None)
        self.activity_category = kwargs.get('activity_category', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ReceiverResponse(Model):
    """ReceiverResponse.

    :param id:
    :type id: long
    :param serial_number:
    :type serial_number: str
    :param firmware_version:
    :type firmware_version: str
    :param network_id:
    :type network_id: str
    :param receiver_type: Possible values include: 'BaseStation', 'Repeater'
    :type receiver_type: str or ~smartdiagnostics_sdk.models.enum
    :param rf_channel:
    :type rf_channel: int
    :param pending_rf_channel:
    :type pending_rf_channel: int
    :param mac_address:
    :type mac_address: str
    :param radio_mac_address:
    :type radio_mac_address: str
    :param location:
    :type location: ~smartdiagnostics_sdk.models.LocationChild
    :param corporation:
    :type corporation: ~smartdiagnostics_sdk.models.CorporationChild
    :param nodes:
    :type nodes: list[~smartdiagnostics_sdk.models.NodeChild]
    :param nickname:
    :type nickname: str
    """

    _attribute_map = {
        'id': {'key': 'Id', 'type': 'long'},
        'serial_number': {'key': 'SerialNumber', 'type': 'str'},
        'firmware_version': {'key': 'FirmwareVersion', 'type': 'str'},
        'network_id': {'key': 'NetworkId', 'type': 'str'},
        'receiver_type': {'key': 'ReceiverType', 'type': 'str'},
        'rf_channel': {'key': 'RfChannel', 'type': 'int'},
        'pending_rf_channel': {'key': 'PendingRfChannel', 'type': 'int'},
        'mac_address': {'key': 'MacAddress', 'type': 'str'},
        'radio_mac_address': {'key': 'RadioMacAddress', 'type': 'str'},
        'location': {'key': 'Location', 'type': 'LocationChild'},
        'corporation': {'key': 'Corporation', 'type': 'CorporationChild'},
        'nodes': {'key': 'Nodes', 'type': '[NodeChild]'},
        'nickname': {'key': 'Nickname', 'type': 'str'},
    }

    def __init__(self, *, id: int=None, serial_number: str=None, firmware_version: str=None, network_id: str=None, receiver_type=None, rf_channel: int=None, pending_rf_channel: int=None, mac_address: str=None, radio_mac_address: str=None, location=None, corporation=None, nodes=None, nickname: str=None, **kwargs) -> None:
        super(ReceiverResponse, self).__init__(**kwargs)
        self.id = id
        self.serial_number = serial_number
        self.firmware_version = firmware_version
        self.network_id = network_id
        self.receiver_type = receiver_type
        self.rf_channel = rf_channel
        self.pending_rf_channel = pending_rf_channel
        self.mac_address = mac_address
        self.radio_mac_address = radio_mac_address
        self.location = location
        self.corporation = corporation
        self.nodes = nodes
        self.nickname = nickname
